==> haskell-blaze-textual-0.2.3.1-28-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 blaze-textual
version:              0.2.3.1
visibility:           public
id:                   blaze-textual-0.2.3.1-IAI0sPjQp9XEjXRwn0MZhY
key:                  blaze-textual-0.2.3.1-IAI0sPjQp9XEjXRwn0MZhY
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:           Andrey Prokopenko <persiantiger@yandex.ru>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             http://github.com/swamp-agr/blaze-textual
synopsis:             Fast rendering of common datatypes
description:
    A library for efficiently rendering Haskell datatypes to
    bytestrings.

    /Note/: if you use GHCi or Template Haskell, please see the
    @README@ file for important details about building this package,
    and other packages that depend on it:
    <https://github.com/swamp-agr/blaze-textual#readme>

category:             Text
abi:                  c306a86745eaa57bafead2bbc41c828f
exposed:              True
exposed-modules:      Blaze.Text Blaze.Text.Double Blaze.Text.Int
hidden-modules:       Blaze.Text.Double.Native
import-dirs:          /usr/lib/ghc-9.2.8/site-local/blaze-textual-0.2.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/blaze-textual-0.2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-textual
hs-libraries:         HSblaze-textual-0.2.3.1-IAI0sPjQp9XEjXRwn0MZhY
depends:
    base-4.16.4.0 blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK
    bytestring-0.11.4.0 ghc-prim-0.8.0 integer-gmp-1.1
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7 text-1.2.5.0
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:
    /usr/share/doc/haskell-blaze-textual/html/blaze-textual.haddock

haddock-html:         /usr/share/doc/haskell-blaze-textual/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-textual-0.2.3.1-56.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 blaze-textual
version:              0.2.3.1
visibility:           public
id:                   blaze-textual-0.2.3.1-ABuKViY2D26F534Sh9YEb
key:                  blaze-textual-0.2.3.1-ABuKViY2D26F534Sh9YEb
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:           Andrey Prokopenko <persiantiger@yandex.ru>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             http://github.com/swamp-agr/blaze-textual
synopsis:             Fast rendering of common datatypes
description:
    A library for efficiently rendering Haskell datatypes to
    bytestrings.

    /Note/: if you use GHCi or Template Haskell, please see the
    @README@ file for important details about building this package,
    and other packages that depend on it:
    <https://github.com/swamp-agr/blaze-textual#readme>

category:             Text
abi:                  f90ebe9f3118b77e274b9af78d2da6e4
exposed:              True
exposed-modules:      Blaze.Text Blaze.Text.Double Blaze.Text.Int
hidden-modules:       Blaze.Text.Double.Native
import-dirs:          /usr/lib/ghc-9.4.8/site-local/blaze-textual-0.2.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/blaze-textual-0.2.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/blaze-textual-0.2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-textual
hs-libraries:         HSblaze-textual-0.2.3.1-ABuKViY2D26F534Sh9YEb
depends:
    base-4.17.2.1 blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS
    bytestring-0.11.5.3 ghc-prim-0.9.1 integer-gmp-1.1
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh text-2.0.2
    vector-0.13.2.0-H3MTIE0bxkOEYwCD854O16

haddock-interfaces:
    /usr/share/doc/haskell-blaze-textual/html/blaze-textual.haddock

haddock-html:         /usr/share/doc/haskell-blaze-textual/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
